# Citations

### 2021
* Glynatsi, Nikoleta E., and Vincent A. Knight. "A bibliometric study of research topics, collaboration, and centrality in the iterated prisoner’s dilemma." Humanities and Social Sciences Communications 8.1 (2021): 1-12. [Nature.com](https://www.nature.com/articles/s41599-021-00718-9) [ArXiv](https://arxiv.org/abs/1911.06128)
* Glynatsi, Nikoleta E., and Vincent A. Knight. "Game Theory and Python: An educational tutorial to game theory and repeated games using Python." Journal of Open Source Education, 4(39), 78. [jose.theoj.org](https://doi.org/10.21105/jose.00078)

### 2020

* Kies, Martin. "Finding Best Answers for the Iterated Prisoner’s Dilemma Using Improved Q-Learning." [Available at SSRN 3556714](https://papers.ssrn.com/sol3/papers.cfm?abstract_id=3556714) (2020).
* Krapohl, Sebastian, Václav Ocelík, and Dawid M. Walentek. "The instability of globalization: applying evolutionary game theory to global trade cooperation." [Public Choice](https://ideas.repec.org/a/kap/pubcho/vyid10.1007_s11127-020-00799-1.html) (2020): 1-21.
* Glynatsi, Nikoleta E., and Vincent A. Knight. "A meta analysis of tournaments and an evaluation of performance in the Iterated Prisoner's Dilemma" arXiv preprint arXiv:2001.05911 (2019). [ArXiv](https://arxiv.org/abs/2001.05911)
* Wang, Shiheng, and Fangzhen Lin. "Nice Invincible Strategy for the Average-Payoff IPD." [Proceedings of the AAAI Conference on Artificial Intelligence](https://aaai.org/ojs/index.php/AAAI/article/view/5604)
* Glynatsi, Nikoleta E., and Vincent A. Knight. "Using a theory of mind to find best responses to memory-one strategies." Sci Rep 10, 17287 (2020). [Scientific Reports](https://doi.org/10.1038/s41598-020-74181-y)


### 2019

* Thomas, Robert W., and José M. Vidal. "Ad Hoc Vehicle Platoon Formation." [2019 SoutheastCon. IEEE](Emergence and Stability of Self-Evolved Cooperative Strategies using Stochastic Machines) (2019)
* T.J. Gaffney, Marc Harper, Vincent A. Knight. "Memory depth of finite state machine strategies for the iterated prisoner's dilemma" arXiv preprint arxiv:1912.04493 (2019). [ArXiv](https://arxiv.org/abs/1912.04493)
* O'Neil, Daniel A., and Mikel D. Petty. "Synthesizing Social Networks with Iterated Prisoners' Dilemma." [Proceedings of the International Conference on Modeling, Simulation and Visualization Methods (MSV).](https://csce.ucmss.com/cr/books/2019/LFS/CSREA2019/MSV2345.pdf) The Steering Committee of The World Congress in Computer Science, Computer Engineering and Applied Computing (WorldComp), 2019.
* Collins, David. "A Genetic Algorithm Approach to the Iterated Prisoner’s Dilemma." [Undergraduate Research in Natural and Clinical Science and Technology Journal](https://urncst.com/index.php/urncst/article/view/155) (2019): 1-9.
* Wang, Shiheng, and Fangzhen Lin. "Invincible Strategies of Iterated Prisoner's Dilemma." Proceedings of the 18th International Conference on Autonomous Agents and MultiAgent Systems. International Foundation for Autonomous Agents and Multiagent Systems, 2019.  [ArXiv](https://arxiv.org/abs/1712.06488)
* Knight, Vincent A., et al. "Recognising and evaluating the effectiveness of extortion in the Iterated Prisoner's Dilemma." arXiv preprint arXiv:1904.00973 (2019). [ArXiv](https://arxiv.org/abs/1904.00973)

### 2018
* Garcia, Julian, and Matthijs van Veelen. "No strategy can win in the repeated prisoner’s dilemma: Linking game theory and computer simulations." Frontiers in Robotics and AI 5.102 (2018) [pdf](https://static1.squarespace.com/static/56d27a10b6aa606b54a190bf/t/5b864ef11ae6cf2ee0c6c207/1535528708649/20.pdf)
* Goodman, Aaron. "Learning multiagent coordination in the absence of communication channels." arXiv:1802.06036 (2018). [ArXiv](https://arxiv.org/abs/1802.06036)
* Knight, Vincent, et al. "Evolution Reinforces Cooperation with the Emergence of Self-Recognition Mechanisms: an empirical study of the Moran process for the iterated Prisoner's dilemma."  PLoS ONE 13(10) (2018): e0204981. [PLOS](https://journals.plos.org/plosone/article?id=10.1371/journal.pone.0204981)
* Latorre, Julian F. and Ospina, Juan Pablo and Ortiz, Jorge E. "A Coalitional Game for Achieving Emergent Cooperation in Ad Hoc Networks Through Sympathy and Commitment." Springer (2018). [Springer](https://link.springer.com/chapter/10.1007/978-3-030-00350-0_30)
* Moura, Jose, and David Hutchison. "Game Theory for Multi-Access Edge Computing: Survey, Use Cases, and Future Trends." IEEE Communications Surveys & Tutorials (2018). [IEEE CS&T](https://ieeexplore.ieee.org/abstract/document/8424815) [ArXiv](https://arxiv.org/abs/1704.00323)
* Neumann, Shai and Sood, Suraj and Hollander, Markus et al. "Using Bots in Strategizing Group Compositions to Improve Decision--Making Processes" Springer (2018). [Springer](https://link.springer.com/chapter/10.1007/978-3-319-91467-1_24)
* Nicolas, Anastassacos and Mirco, Musolesi. "Learning through Probing: a decentralized reinforcement learning architecture for social dilemmas." arXiv preprint arXiv:1809.10007 (2018). [ArXiv](https://arxiv.org/abs/1809.10007)
* Skiba, Grażyna, et al. "Flexible asynchronous simulation of iterated prisoner’s dilemma based on actor model." Simulation Modelling Practice and Theory 83 (2018): 75-92.

### 2017

* Harper, Marc, et al. "Reinforcement learning produces dominant strategies for the Iterated Prisoner’s Dilemma." PloS one 12.12 (2017): e0188046.  [PLOS](http://journals.plos.org/plosone/article?id=10.1371/journal.pone.0188046)

### 2016

* Knight, Vincent Anthony, et al. "An open framework for the reproducible study of the iterated prisoner's dilemma." Journal of Open Research Software 4.1 (2016). [JORS](https://openresearchsoftware.metajnl.com/articles/10.5334/jors.125/) [ArXiv](https://arxiv.org/abs/1604.00896)

### 2015

* Knight, Vincent. "Playing Games: A Case Study in Active Learning Applied to Game Theory." [MSOR Connections 14.1 (2015): 28-38](https://journals.gre.ac.uk/index.php/msor/article/download/254/254).

### Disserations

* Dollbo, Anna. MIXED MEMORY Q-LEARNER: An adaptive reinforcement learning algorithm for the Iterated Prisoner’s Dilemma. [BS thesis](https://gupea.ub.gu.se/handle/2077/69664). 2021.
* Glynatsi, Nikoleta. "Understanding responses to environments for the Prisoner's Dilemma: A meta analysis, multidimensional optimisation and machine learning approach". PhD Thesis, Cardiff University. (2020) [Available Online](http://orca.cf.ac.uk/135221/).
* Santana, Jonas Cardoso Carvalho. "Aprendizado de máquina e o dilema dos prisioneiros". (2020)
* Black, Ben. "An Empirical Evaluation of the Ohtsuki-Nowak Approximation." [Master's Thesis](https://www.lancaster.ac.uk/~blackb/documents/MScDiss.pdf). (2018).
* Hayes, Victoria. The Evolution of Cooperation: A Recreation of Axelrod's Computer Tournament. The University of North Carolina at Greensboro, (2017). [PDF](http://libres.uncg.edu/ir/uncg/f/Hayes_uncg_0154M_12243.pdf)
* Latorre Ochoa, Julian Felipe. "Compromiso y simpatía: emotividad en la toma de decisiones cooperativas en redes estocásticas de siguiente generación". [Available online](https://repositorio.unal.edu.co/handle/unal/60956) (2017)
